# RPM spec file for Xconq
# For Tcl/Tk interface on most RPM-based Linux distros.
# Attempts some compliance with FHS 2.2 and conventions used by 
#  Redhat and Mandrake.

%define name		xconq

%define version		7.5.0
# To prevent Epoch madness, we now use the fairly common trick of 
#  making snapshots and prereleases be Release "0pre".
%define prereleaselvl	0
%define releaselvl	0pre
%define releasedate	20040519
# For a release:
# %define release		%{releaselvl}
# For a prerelease:
# %define release		%{releaselvl}.%{prereleaselvl}.0
# For a CVS snapshot:
%define release		%{releaselvl}.%{prereleaselvl}.%{releasedate}

Name: %{name}

Summary: General turn-based 2D strategy game system
# We need to use the Epoch tag to trump some of the older versions 
#  floating around which had version number based on date only.
#  Epoch should NOT be incremented again. See the release comment.
Epoch: 1
Version: %{version}
Release: %{release}

URL: http://sources.redhat.com/xconq
License: GPL
Packager: Xconq Team <xconq7 [at] sources [dot] redhat [dot] com>

Group: Amusements/Games/Strategy

#Source: ftp://sources.redhat.com/pub/xconq/xconq-7.4.0.tar.gz
# For CVS builds we use a local tarball.
Source0: xconq-%{releasedate}.tar.gz

%define buildroot   %{_tmppath}/%{name}-%{version}-%{release}-BUILDROOT
BuildRoot: %{buildroot}

#Requires: tcl
#Requires: tk
# RPM can autodetect such dependencies.

%description
Xconq is a general strategy game system.  It is a complete system that
includes all the components: a portable engine, graphical interfaces
for Unix/Linux/X11, Macintosh, and Windows, multiple AIs, networking
for multi-player games, and an extensive game library.

In addition to Xconq's "standard" game, which is similar to the
classic Empire/Empire Deluxe games of years ago, the game library
includes games for ancient civilizations, the Peloponnesian War, the
Roman Civil War, Frederician strategy, Napoleonic strategy, Gettysburg
at a brigade scale, the Russian revolution, the Normandy invasion,
WWII at scales from tactical to grand strategic, Beirut street
fighting, voyages of discovery, African exploration, and many others,
including space and fantasy games.

As befits its emphasis on strategy, Xconq's forte is turn-based play
using overhead views of a tiled world.  The world is basically
two-dimensional, although varying elevations are available for games
that need elevation effects or line-of-sight.  Xconq is especially
interesting for games about unusual or lesser-known strategic
situations; it is unique in providing a single system for modelling
the conflicts and strategies of any period in history.

%prep
%setup

%build
./configure --prefix=%{buildroot}/usr --bindir=%{buildroot}/usr/games --datadir=%{buildroot}/usr/share/xconq --infodir=%{buildroot}/usr/share/info --mandir=%{buildroot}/usr/share/man --enable-alternate-scoresdir=%{buildroot}/var/lib/games/xconq --enable-alternate-gameuser=`id -u` --enable-alternate-gamegroup=`id -g`
make
make info

%install
rm -rf %{buildroot}
xconq_scores_dir=%{buildroot}/var/lib/games/xconq
if [ ! -d ${xconq_scores_dir} ]; then
  mkdir -p ${xconq_scores_dir}
fi
xconq_doc_dir=%{buildroot}/usr/share/doc/xconq-7.5
if [ ! -d ${xconq_doc_dir} ]; then
  mkdir -p ${xconq_doc_dir}
fi
make install
make install-info
cp -f README* INSTALL* ChangeLog* NEWS COPYING ${xconq_doc_dir}
if [ ! -d ${xconq_doc_dir}/html ]; then
  mkdir ${xconq_doc_dir}/html
fi
cp doc/*.html ${xconq_doc_dir}/html

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,0755)
/usr/games/imf2x
/usr/games/x2imf
/usr/games/xconq
/usr/games/imfapp
/usr/share/xconq
# Indicate in the RPM DB that the following are documentation:
%doc /usr/share/info/xconq.info*
%doc /usr/share/info/xcdesign.info*
%doc /usr/share/info/hacking.info*
# The bloody new 'rpm-build' compresses the man page and then isn't smart 
#  enough to figure out that it has a .gz or .bz2 extension. Brilliant....
#  So we have to put a wildcard after a single file to handle different 
#  versions of 'rpm-build'.
%doc /usr/share/man/man6/xconq.6*
%docdir /usr/share/doc/xconq-7.5
/usr/share/doc/xconq-7.5
# Just want the directory, not any scorefiles that might be in it
%dir /var/lib/games/xconq

%changelog

* Tue May 18 2004 Eric McDonald <mcdonald@sources.redhat.com>
- Release new RPM (last release: 2003/11); see ChangeLog for details.
- Update RPM spec file to build RPM without root.
- Update RPM spec file to include ChangeLog.
